template <typename T>
inline Vector5<T>::Vector5() :
x(0),
y(0),
z(0),
w(0),
v(0)
{

}

template <typename T>
inline Vector5<T>::Vector5(T X, T Y, T Z, T W, T V) :
x(X),
y(Y),
z(Z),
w(W),
v(V)
{

}

template <typename T>
template <typename U>
inline Vector5<T>::Vector5(const Vector5<U>& vector) :
x(static_cast<T>(vector.x)),
y(static_cast<T>(vector.y)),
z(static_cast<T>(vector.z)),
w(static_cast<T>(vector.w)),
v(static_cast<T>(vector.v))
{
}

template <typename T>
inline Vector5<T> operator -(const Vector5<T>& right)
{
    return Vector5<T>(-right.x, -right.y, -right.z, -right.w, -right.v);
}

template <typename T>
inline Vector5<T>& operator +=(Vector5<T>& left, const Vector5<T>& right)
{
    left.x += right.x;
    left.y += right.y;
    left.z += right.z;
    left.w += right.w;
	left.v += right.v;
    return left;
}

template <typename T>
inline Vector5<T>& operator -=(Vector5<T>& left, const Vector5<T>& right)
{
    left.x -= right.x;
    left.y -= right.y;
    left.z -= right.z;
    left.w -= right.w;
	left.v -= right.v;
    return left;
}

template <typename T>
inline Vector5<T> operator +(const Vector5<T>& left, const Vector5<T>& right)
{
    return Vector5<T>(left.x + right.x, left.y + right.y, left.z + right.z, left.w + right.w, left.v + right.v);
}

template <typename T>
inline Vector5<T> operator -(const Vector5<T>& left, const Vector5<T>& right)
{
    return Vector5<T>(left.x - right.x, left.y - right.y, left.z - right.z, left.w - right.w, left.v - right.v);
}

template <typename T>
inline Vector5<T> operator *(const Vector5<T>& left, T right)
{
    return Vector5<T>(left.x * right, left.y * right, left.z * right, left.w * right, left.v * right);
}

template <typename T>
inline Vector5<T> operator *(T left, const Vector5<T>& right)
{
    return Vector5<T>(right.x * left, right.y * left, right.z * left, right.w * left, right.v * left);
}

template <typename T>
inline Vector5<T>& operator *=(Vector5<T>& left, T right)
{
    left.x *= right;
    left.y *= right;
    left.z *= right;
    left.w *= right;
	left.v *= right;
    return left;
}

template <typename T>
inline Vector5<T> operator /(const Vector5<T>& left, T right)
{
    return Vector5<T>(left.x / right, left.y / right, left.z / right, left.w / right, left.v / right);
}

template <typename T>
inline Vector5<T>& operator /=(Vector5<T>& left, T right)
{
    left.x /= right;
    left.y /= right;
    left.z /= right;
    left.w /= right;
	left.v /= right;
    return left;
}

template <typename T>
inline bool operator ==(const Vector5<T>& left, const Vector5<T>& right)
{
    return (left.x == right.x) && (left.y == right.y) && (left.z == right.z) && (left.w == right.w) && (left.v == right.v);
}

template <typename T>
inline bool operator !=(const Vector5<T>& left, const Vector5<T>& right)
{
    return (left.x != right.x) || (left.y != right.y) || (left.z != right.z) || (left.w != right.w) || (left.v != right.v);
}
